@@ -1,13 +1,22 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: site_kpi_summaries_query_count
-short_description: Resource module for Site Kpi Summaries Query Count
+short_description: Resource module for Site Kpi Summaries
+  Query Count
 description:
-  - This module represents an alias of the module site_kpi_summaries_query_count_v1
+  - Manage operation create of the resource Site Kpi
+    Summaries Query Count. - > Returns the total number
+    of site analytics records available for for given
+    set of filters. For detailed information about the
+    usage of the API, please refer to the Open API specification
+    document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
+    SiteKpiSummaries-1.0.0-resolved.yaml.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -37,21 +46,22 @@ options:
     description: Start Time.
     type: int
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Sites GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFiltersV1
-    description: Complete reference of the GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFiltersV1
+  - name: Cisco DNA Center documentation for Sites GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFilters
+    description: Complete reference of the GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFilters
       API.
-    link:
-      https://developer.cisco.com/docs/dna-center/#!get-the-total-number-of-site-analytics-records-available-for-for-given-set-of-filters
+    link: https://developer.cisco.com/docs/dna-center/#!get-the-total-number-of-site-analytics-records-available-for-for-given-set-of-filters
 notes:
   - SDK Method used are
-    sites.Sites.get_the_total_number_of_site_analytics_records_available_for_for_given_set_of_filters_v1,
-  - Paths used are post /dna/data/api/v1/siteKpiSummaries/query/count,
-  - It should be noted that this module is an alias of site_kpi_summaries_query_count_v1
+    sites.Sites.get_the_total_number_of_site_analytics_records_available_for_for_given_set_of_filters,
+  - Paths used are
+    post /dna/data/api/v1/siteKpiSummaries/query/count,
 """
+
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.site_kpi_summaries_query_count:
     dnac_host: "{{dnac_host}}"
