@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2018, Luca 'remix_tj' Lorenzetto <lorenzetto.luca@gmail.com>
 #
@@ -7,10 +6,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 
-from __future__ import (absolute_import, division, print_function)
-
-__metaclass__ = type
-
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: emc_vnx_sg_member
@@ -77,7 +73,7 @@ EXAMPLES = r"""
 
 RETURN = r"""
 hluid:
-  description: LUNID that hosts attached to the storage group will see.
+  description: LUNID visible to hosts attached to the storage group.
   type: int
   returned: success
 """
@@ -85,14 +81,19 @@ hluid:
 import traceback
 
 from ansible.module_utils.basic import AnsibleModule, missing_required_lib
-from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.general.plugins.module_utils.storage.emc.emc_vnx import emc_vnx_argument_spec
 
 LIB_IMP_ERR = None
 try:
     from storops import VNXSystem
-    from storops.exception import VNXCredentialError, VNXStorageGroupError, \
-        VNXAluAlreadyAttachedError, VNXAttachAluError, VNXDetachAluNotFoundError
+    from storops.exception import (
+        VNXCredentialError,
+        VNXStorageGroupError,
+        VNXAluAlreadyAttachedError,
+        VNXAttachAluError,
+        VNXDetachAluNotFoundError,
+    )
+
     HAS_LIB = True
 except Exception:
     LIB_IMP_ERR = traceback.format_exc()
@@ -101,31 +102,24 @@ except Exception:
 
 def run_module():
     module_args = dict(
-        name=dict(type='str', required=True),
-        lunid=dict(type='int', required=True),
-        state=dict(default='present', choices=['present', 'absent']),
+        name=dict(type="str", required=True),
+        lunid=dict(type="int", required=True),
+        state=dict(default="present", choices=["present", "absent"]),
     )
 
     module_args.update(emc_vnx_argument_spec)
 
-    result = dict(
-        changed=False,
-        hluid=None
-    )
+    result = dict(changed=False, hluid=None)
 
-    module = AnsibleModule(
-        argument_spec=module_args,
-        supports_check_mode=True
-    )
+    module = AnsibleModule(argument_spec=module_args, supports_check_mode=True)
 
     if not HAS_LIB:
-        module.fail_json(msg=missing_required_lib('storops >= 0.5.10'),
-                         exception=LIB_IMP_ERR)
+        module.fail_json(msg=missing_required_lib("storops >= 0.5.10"), exception=LIB_IMP_ERR)
 
-    sp_user = module.params['sp_user']
-    sp_address = module.params['sp_address']
-    sp_password = module.params['sp_password']
-    alu = module.params['lunid']
+    sp_user = module.params["sp_user"]
+    sp_address = module.params["sp_address"]
+    sp_password = module.params["sp_password"]
+    alu = module.params["lunid"]
 
     # if the user is working with this module in only check mode we do not
     # want to make any changes to the environment, just return the current
@@ -135,38 +129,32 @@ def run_module():
 
     try:
         vnx = VNXSystem(sp_address, sp_user, sp_password)
-        sg = vnx.get_sg(module.params['name'])
+        sg = vnx.get_sg(module.params["name"])
         if sg.existed:
-            if module.params['state'] == 'present':
+            if module.params["state"] == "present":
                 if not sg.has_alu(alu):
                     try:
-                        result['hluid'] = sg.attach_alu(alu)
-                        result['changed'] = True
+                        result["hluid"] = sg.attach_alu(alu)
+                        result["changed"] = True
                     except VNXAluAlreadyAttachedError:
-                        result['hluid'] = sg.get_hlu(alu)
+                        result["hluid"] = sg.get_hlu(alu)
                     except (VNXAttachAluError, VNXStorageGroupError) as e:
-                        module.fail_json(msg='Error attaching {0}: '
-                                             '{1} '.format(alu, to_native(e)),
-                                         **result)
+                        module.fail_json(msg=f"Error attaching {alu}: {e} ", **result)
                 else:
-                    result['hluid'] = sg.get_hlu(alu)
-            if module.params['state'] == 'absent' and sg.has_alu(alu):
+                    result["hluid"] = sg.get_hlu(alu)
+            if module.params["state"] == "absent" and sg.has_alu(alu):
                 try:
                     sg.detach_alu(alu)
-                    result['changed'] = True
+                    result["changed"] = True
                 except VNXDetachAluNotFoundError:
                     # being not attached when using absent is OK
                     pass
                 except VNXStorageGroupError as e:
-                    module.fail_json(msg='Error detaching alu {0}: '
-                                         '{1} '.format(alu, to_native(e)),
-                                     **result)
+                    module.fail_json(msg=f"Error detaching alu {alu}: {e} ", **result)
         else:
-            module.fail_json(msg='No such storage group named '
-                                 '{0}'.format(module.params['name']),
-                                 **result)
+            module.fail_json(msg=f"No such storage group named {module.params['name']}", **result)
     except VNXCredentialError as e:
-        module.fail_json(msg='{0}'.format(to_native(e)), **result)
+        module.fail_json(msg=f"{e}", **result)
 
     module.exit_json(**result)
 
@@ -175,5 +163,5 @@ def main():
     run_module()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
