@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,26 +92,31 @@ options:
         required: false
         type: dict
         suboptions:
-            ac-ip:
+            ac_ip:
+                aliases: ['ac-ip']
                 type: str
-                description: Deprecated, please rename it to ac_ip. IP address of the validation controller that AP must be able to join after applying...
-            ac-port:
+                description: IP address of the validation controller that AP must be able to join after applying AP local configuration.
+            ac_port:
+                aliases: ['ac-port']
                 type: int
-                description: Deprecated, please rename it to ac_port. Port of the validation controller that AP must be able to join after applying AP ...
-            ac-timer:
+                description: Port of the validation controller that AP must be able to join after applying AP local configuration
+            ac_timer:
+                aliases: ['ac-timer']
                 type: int
-                description: Deprecated, please rename it to ac_timer. Maximum waiting time for the AP to join the validation controller after applying...
-            ac-type:
+                description: Maximum waiting time for the AP to join the validation controller after applying AP local configuration
+            ac_type:
+                aliases: ['ac-type']
                 type: str
-                description: Deprecated, please rename it to ac_type. Validation controller type
+                description: Validation controller type
                 choices:
                     - 'default'
                     - 'specify'
                     - 'apcfg'
-            command-list:
+            command_list:
+                aliases: ['command-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to command_list. Command list.
+                description: Command list.
                 suboptions:
                     id:
                         type: int
@@ -116,9 +124,10 @@ options:
                     name:
                         type: str
                         description: AP local configuration command name.
-                    passwd-value:
+                    passwd_value:
+                        aliases: ['passwd-value']
                         type: raw
-                        description: (list) Deprecated, please rename it to passwd_value. AP local configuration command password value.
+                        description: (list) AP local configuration command password value.
                     type:
                         type: str
                         description: The command type
@@ -135,9 +144,10 @@ options:
                 type: str
                 description: AP local configuration profile name.
                 required: true
-            ap-family:
+            ap_family:
+                aliases: ['ap-family']
                 type: str
-                description: Deprecated, please rename it to ap_family. FortiAP family type
+                description: FortiAP family type
                 choices:
                     - 'fap'
                     - 'fap-u'
@@ -148,6 +158,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -156,27 +167,26 @@ EXAMPLES = '''
     - name: Configure AP local configuration profiles.
       fortinet.fortimanager.fmgr_apcfgprofile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         apcfgprofile:
-          ac_ip: <string>
-          ac_port: <integer>
-          ac_timer: <integer>
-          ac_type: <value in [default, specify, apcfg]>
-          command_list:
-            -
-              id: <integer>
-              name: <string>
-              passwd_value: <list or string>
-              type: <value in [non-password, password]>
-              value: <string>
-          comment: <string>
-          name: <string>
-          ap_family: <value in [fap, fap-u, fap-c]>
+          name: "your value" # Required variable, string
+          # ac_ip: <string>
+          # ac_port: <integer>
+          # ac_timer: <integer>
+          # ac_type: <value in [default, specify, apcfg]>
+          # command_list:
+          #   - id: <integer>
+          #     name: <string>
+          #     passwd_value: <list or string>
+          #     type: <value in [non-password, password]>
+          #     value: <string>
+          # comment: <string>
+          # ap_family: <value in [fap, fap-u, fap-c]>
 '''
 
 RETURN = '''
@@ -220,27 +230,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/wireless-controller/apcfg-profile',
         '/pm/config/global/obj/wireless-controller/apcfg-profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/wireless-controller/apcfg-profile/{apcfg-profile}',
-        '/pm/config/global/obj/wireless-controller/apcfg-profile/{apcfg-profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'apcfgprofile': {
             'type': 'dict',
             'v_range': [['6.4.6', '']],
@@ -263,9 +266,8 @@ def main():
                 },
                 'comment': {'v_range': [['6.4.6', '']], 'type': 'str'},
                 'name': {'v_range': [['6.4.6', '']], 'required': True, 'type': 'str'},
-                'ap-family': {'v_range': [['6.4.8', '6.4.14'], ['7.0.2', '']], 'choices': ['fap', 'fap-u', 'fap-c'], 'type': 'str'}
+                'ap-family': {'v_range': [['6.4.8', '6.4.15'], ['7.0.2', '']], 'choices': ['fap', 'fap-u', 'fap-c'], 'type': 'str'}
             }
-
         }
     }
 
@@ -274,14 +276,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'apcfgprofile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
