@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -93,10 +96,11 @@ options:
         required: false
         type: dict
         suboptions:
-            access-rule:
+            access_rule:
+                aliases: ['access-rule']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to access_rule.
+                description: Access rule.
                 suboptions:
                     action:
                         type: str
@@ -108,7 +112,7 @@ options:
                     bypass:
                         type: list
                         elements: str
-                        description: No description.
+                        description: CASB bypass options.
                         choices:
                             - 'av'
                             - 'dlp'
@@ -118,10 +122,32 @@ options:
                     name:
                         type: str
                         description: CASB access rule activity name.
-            custom-control:
+                    attribute_filter:
+                        aliases: ['attribute-filter']
+                        type: list
+                        elements: dict
+                        description: Attribute filter.
+                        suboptions:
+                            action:
+                                type: str
+                                description: CASB access rule tenant control action.
+                                choices:
+                                    - 'block'
+                                    - 'monitor'
+                                    - 'bypass'
+                            attribute_match:
+                                aliases: ['attribute-match']
+                                type: list
+                                elements: str
+                                description: CASB access rule tenant match.
+                            id:
+                                type: int
+                                description: CASB tenant control ID.
+            custom_control:
+                aliases: ['custom-control']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to custom_control.
+                description: Custom control.
                 suboptions:
                     name:
                         type: str
@@ -129,25 +155,49 @@ options:
                     option:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Option.
                         suboptions:
                             name:
                                 type: str
                                 description: CASB custom control option name.
-                            user-input:
+                            user_input:
+                                aliases: ['user-input']
                                 type: list
                                 elements: str
-                                description: Deprecated, please rename it to user_input.
-            domain-control:
+                                description: CASB custom control user input.
+                    attribute_filter:
+                        aliases: ['attribute-filter']
+                        type: list
+                        elements: dict
+                        description: Attribute filter.
+                        suboptions:
+                            action:
+                                type: str
+                                description: CASB access rule tenant control action.
+                                choices:
+                                    - 'block'
+                                    - 'monitor'
+                                    - 'bypass'
+                            attribute_match:
+                                aliases: ['attribute-match']
+                                type: list
+                                elements: str
+                                description: CASB access rule tenant match.
+                            id:
+                                type: int
+                                description: CASB tenant control ID.
+            domain_control:
+                aliases: ['domain-control']
                 type: str
-                description: Deprecated, please rename it to domain_control. Enable/disable domain control.
+                description: Enable/disable domain control.
                 choices:
                     - 'disable'
                     - 'enable'
-            domain-control-domains:
+            domain_control_domains:
+                aliases: ['domain-control-domains']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to domain_control_domains.
+                description: CASB profile domain control domains.
             log:
                 type: str
                 description: Enable/disable log settings.
@@ -158,38 +208,65 @@ options:
                 type: str
                 description: CASB profile SaaS application name.
                 required: true
-            safe-search:
+            safe_search:
+                aliases: ['safe-search']
                 type: str
-                description: Deprecated, please rename it to safe_search. Enable/disable safe search.
+                description: Enable/disable safe search.
                 choices:
                     - 'disable'
                     - 'enable'
-            safe-search-control:
+            safe_search_control:
+                aliases: ['safe-search-control']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to safe_search_control.
-            tenant-control:
+                description: CASB profile safe search control.
+            tenant_control:
+                aliases: ['tenant-control']
                 type: str
-                description: Deprecated, please rename it to tenant_control. Enable/disable tenant control.
+                description: Enable/disable tenant control.
                 choices:
                     - 'disable'
                     - 'enable'
-            tenant-control-tenants:
+            tenant_control_tenants:
+                aliases: ['tenant-control-tenants']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to tenant_control_tenants.
+                description: CASB profile tenant control tenants.
             status:
                 type: str
                 description: Enable/disable setting.
                 choices:
                     - 'disable'
                     - 'enable'
+            advanced_tenant_control:
+                aliases: ['advanced-tenant-control']
+                type: list
+                elements: dict
+                description: Advanced tenant control.
+                suboptions:
+                    attribute:
+                        type: list
+                        elements: dict
+                        description: Attribute.
+                        suboptions:
+                            input:
+                                type: list
+                                elements: str
+                                description: CASB extend user input value.
+                            name:
+                                type: str
+                                description: CASB extend user input name.
+                    name:
+                        type: list
+                        elements: str
+                        description: CASB advanced tenant control name.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -198,40 +275,50 @@ EXAMPLES = '''
     - name: CASB profile SaaS application.
       fortinet.fortimanager.fmgr_casb_profile_saasapplication:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         state: present # <value in [present, absent]>
         casb_profile_saasapplication:
-          access_rule:
-            -
-              action: <value in [block, bypass, monitor]>
-              bypass:
-                - av
-                - dlp
-                - web-filter
-                - file-filter
-                - video-filter
-              name: <string>
-          custom_control:
-            -
-              name: <string>
-              option:
-                -
-                  name: <string>
-                  user_input: <list or string>
-          domain_control: <value in [disable, enable]>
-          domain_control_domains: <list or string>
-          log: <value in [disable, enable]>
-          name: <string>
-          safe_search: <value in [disable, enable]>
-          safe_search_control: <list or string>
-          tenant_control: <value in [disable, enable]>
-          tenant_control_tenants: <list or string>
-          status: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # access_rule:
+          #   - action: <value in [block, bypass, monitor]>
+          #     bypass:
+          #       - "av"
+          #       - "dlp"
+          #       - "web-filter"
+          #       - "file-filter"
+          #       - "video-filter"
+          #     name: <string>
+          #     attribute_filter:
+          #       - action: <value in [block, monitor, bypass]>
+          #         attribute_match: <list or string>
+          #         id: <integer>
+          # custom_control:
+          #   - name: <string>
+          #     option:
+          #       - name: <string>
+          #         user_input: <list or string>
+          #     attribute_filter:
+          #       - action: <value in [block, monitor, bypass]>
+          #         attribute_match: <list or string>
+          #         id: <integer>
+          # domain_control: <value in [disable, enable]>
+          # domain_control_domains: <list or string>
+          # log: <value in [disable, enable]>
+          # safe_search: <value in [disable, enable]>
+          # safe_search_control: <list or string>
+          # tenant_control: <value in [disable, enable]>
+          # tenant_control_tenants: <list or string>
+          # status: <value in [disable, enable]>
+          # advanced_tenant_control:
+          #   - attribute:
+          #       - input: <list or string>
+          #         name: <string>
+          #     name: <list or string>
 '''
 
 RETURN = '''
@@ -275,28 +362,21 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/casb/profile/{profile}/saas-application',
         '/pm/config/global/obj/casb/profile/{profile}/saas-application'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/casb/profile/{profile}/saas-application/{saas-application}',
-        '/pm/config/global/obj/casb/profile/{profile}/saas-application/{saas-application}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'casb_profile_saasapplication': {
             'type': 'dict',
             'v_range': [['7.4.1', '']],
@@ -312,7 +392,17 @@ def main():
                             'choices': ['av', 'dlp', 'web-filter', 'file-filter', 'video-filter'],
                             'elements': 'str'
                         },
-                        'name': {'v_range': [['7.4.1', '']], 'type': 'str'}
+                        'name': {'v_range': [['7.4.1', '']], 'type': 'str'},
+                        'attribute-filter': {
+                            'v_range': [['7.6.2', '']],
+                            'type': 'list',
+                            'options': {
+                                'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor', 'bypass'], 'type': 'str'},
+                                'attribute-match': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                'id': {'v_range': [['7.6.2', '']], 'type': 'int'}
+                            },
+                            'elements': 'dict'
+                        }
                     },
                     'elements': 'dict'
                 },
@@ -329,6 +419,16 @@ def main():
                                 'user-input': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'}
                             },
                             'elements': 'dict'
+                        },
+                        'attribute-filter': {
+                            'v_range': [['7.6.2', '']],
+                            'type': 'list',
+                            'options': {
+                                'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor', 'bypass'], 'type': 'str'},
+                                'attribute-match': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                'id': {'v_range': [['7.6.2', '']], 'type': 'int'}
+                            },
+                            'elements': 'dict'
                         }
                     },
                     'elements': 'dict'
@@ -341,9 +441,25 @@ def main():
                 'safe-search-control': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'},
                 'tenant-control': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'tenant-control-tenants': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'},
-                'status': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'status': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'advanced-tenant-control': {
+                    'v_range': [['7.6.2', '']],
+                    'type': 'list',
+                    'options': {
+                        'attribute': {
+                            'v_range': [['7.6.2', '']],
+                            'type': 'list',
+                            'options': {
+                                'input': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                'name': {'v_range': [['7.6.2', '']], 'type': 'str'}
+                            },
+                            'elements': 'dict'
+                        },
+                        'name': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'}
+                    },
+                    'elements': 'dict'
+                }
             }
-
         }
     }
 
@@ -352,17 +468,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'casb_profile_saasapplication'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
