@@ -104,6 +104,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -112,8 +113,8 @@ EXAMPLES = '''
     - name: Configure multiple FortiManager units and private servers.
       fortinet.fortimanager.fmgr_fmupdate_serveraccesspriorities_privateserver:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
