@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -113,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -121,19 +125,18 @@ EXAMPLES = '''
     - name: IE white list.
       fortinet.fortimanager.fmgr_gtp_iewhitelist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         gtp_iewhitelist:
-          entries:
-            -
-              id: <integer>
-              ie: <integer>
-              fmgr_message: <integer>
-          name: <string>
+          name: "your value" # Required variable, string
+          # entries:
+          #   - id: <integer>
+          #     ie: <integer>
+          #     fmgr_message: <integer>
 '''
 
 RETURN = '''
@@ -190,6 +193,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'gtp_iewhitelist': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
