@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -589,6 +592,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -688,111 +692,124 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_policy6': {
             'type': 'dict',
-            'v_range': [['6.0.0', '']],
+            'v_range': [['6.0.0', '7.6.2']],
             'options': {
-                'action': {'choices': ['deny', 'accept', 'ipsec', 'ssl-vpn'], 'type': 'str'},
-                'app-category': {'type': 'raw'},
-                'application': {'type': 'raw'},
-                'application-list': {'type': 'str'},
-                'auto-asic-offload': {'v_range': [['6.0.0', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'av-profile': {'type': 'str'},
-                'comments': {'type': 'str'},
-                'custom-log-fields': {'type': 'raw'},
+                'action': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['deny', 'accept', 'ipsec', 'ssl-vpn'], 'type': 'str'},
+                'app-category': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'application': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'application-list': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'auto-asic-offload': {
+                    'v_range': [['6.0.0', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'av-profile': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'comments': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'custom-log-fields': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
                 'devices': {'v_range': [['6.0.0', '7.2.1']], 'type': 'raw'},
-                'diffserv-forward': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'diffserv-reverse': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'diffservcode-forward': {'type': 'str'},
-                'diffservcode-rev': {'type': 'str'},
-                'dlp-sensor': {'type': 'str'},
+                'diffserv-forward': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'diffserv-reverse': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'diffservcode-forward': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'diffservcode-rev': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'dlp-sensor': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
                 'dscp-match': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'dscp-negate': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'dscp-value': {'v_range': [['6.0.0', '7.2.1']], 'type': 'str'},
-                'dsri': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'dstaddr': {'type': 'raw'},
-                'dstaddr-negate': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'dstintf': {'type': 'raw'},
-                'firewall-session-dirty': {'choices': ['check-all', 'check-new'], 'type': 'str'},
-                'fixedport': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'global-label': {'type': 'str'},
-                'groups': {'type': 'raw'},
-                'icap-profile': {'type': 'str'},
-                'inbound': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'ippool': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'ips-sensor': {'type': 'str'},
-                'label': {'type': 'str'},
-                'logtraffic': {'choices': ['disable', 'enable', 'all', 'utm'], 'type': 'str'},
-                'logtraffic-start': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'mms-profile': {'v_range': [['6.0.0', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'},
-                'name': {'type': 'str'},
-                'nat': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'natinbound': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'natoutbound': {'choices': ['disable', 'enable'], 'type': 'str'},
+                'dsri': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dstaddr': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'dstaddr-negate': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dstintf': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'firewall-session-dirty': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['check-all', 'check-new'], 'type': 'str'},
+                'fixedport': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'global-label': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'groups': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'icap-profile': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'inbound': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ippool': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ips-sensor': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'label': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'logtraffic': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable', 'all', 'utm'], 'type': 'str'},
+                'logtraffic-start': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'mms-profile': {'v_range': [['6.0.0', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']], 'type': 'str'},
+                'name': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'nat': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'natinbound': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'natoutbound': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'np-accelation': {'v_range': [['6.0.0', '6.4.15']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'outbound': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'per-ip-shaper': {'type': 'str'},
-                'policyid': {'required': True, 'type': 'int'},
-                'poolname': {'type': 'raw'},
-                'profile-group': {'type': 'str'},
-                'profile-protocol-options': {'v_range': [['6.0.0', '7.2.1'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'},
-                'profile-type': {'choices': ['single', 'group'], 'type': 'str'},
-                'replacemsg-override-group': {'type': 'str'},
-                'rsso': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'schedule': {'type': 'str'},
-                'send-deny-packet': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'service': {'type': 'raw'},
-                'service-negate': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'session-ttl': {'type': 'raw'},
+                'outbound': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'per-ip-shaper': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'policyid': {'v_range': [['6.0.0', '7.6.2']], 'required': True, 'type': 'int'},
+                'poolname': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'profile-group': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'profile-protocol-options': {'v_range': [['6.0.0', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']], 'type': 'str'},
+                'profile-type': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['single', 'group'], 'type': 'str'},
+                'replacemsg-override-group': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'rsso': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'schedule': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'send-deny-packet': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'service': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'service-negate': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'session-ttl': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
                 'spamfilter-profile': {'v_range': [['6.0.0', '7.2.1']], 'type': 'str'},
-                'srcaddr': {'type': 'raw'},
-                'srcaddr-negate': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'srcintf': {'type': 'raw'},
-                'ssl-mirror': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssl-mirror-intf': {'type': 'raw'},
-                'ssl-ssh-profile': {'v_range': [['6.0.0', '7.2.1'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'},
-                'status': {'choices': ['disable', 'enable'], 'type': 'str'},
+                'srcaddr': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'srcaddr-negate': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'srcintf': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'ssl-mirror': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ssl-mirror-intf': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'ssl-ssh-profile': {'v_range': [['6.0.0', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']], 'type': 'str'},
+                'status': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'tags': {'v_range': [['6.0.0', '6.4.15']], 'type': 'str'},
-                'tcp-mss-receiver': {'type': 'int'},
-                'tcp-mss-sender': {'type': 'int'},
-                'tcp-session-without-syn': {'choices': ['all', 'data-only', 'disable'], 'type': 'str'},
-                'timeout-send-rst': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'traffic-shaper': {'type': 'str'},
-                'traffic-shaper-reverse': {'type': 'str'},
-                'url-category': {'type': 'raw'},
-                'users': {'type': 'raw'},
-                'utm-status': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'uuid': {'type': 'str'},
-                'vlan-cos-fwd': {'type': 'int'},
-                'vlan-cos-rev': {'type': 'int'},
-                'voip-profile': {'type': 'str'},
-                'vpntunnel': {'type': 'str'},
-                'webfilter-profile': {'type': 'str'},
-                'anti-replay': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'app-group': {'v_range': [['6.2.0', '']], 'type': 'raw'},
-                'cifs-profile': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'dnsfilter-profile': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'emailfilter-profile': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'http-policy-redirect': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'inspection-mode': {'v_range': [['6.2.0', '']], 'choices': ['proxy', 'flow'], 'type': 'str'},
-                'np-acceleration': {'v_range': [['6.2.0', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'ssh-filter-profile': {'v_range': [['6.2.0', '7.2.1'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'},
-                'ssh-policy-redirect': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'tos': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'tos-mask': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'tos-negate': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'vlan-filter': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'waf-profile': {'v_range': [['6.2.1', '']], 'type': 'str'},
-                'webcache': {'v_range': [['6.2.1', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'webcache-https': {'v_range': [['6.2.1', '7.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'webproxy-forward-server': {'v_range': [['6.2.1', '']], 'type': 'str'},
-                'webproxy-profile': {'v_range': [['6.2.1', '']], 'type': 'str'},
+                'tcp-mss-receiver': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'tcp-mss-sender': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'tcp-session-without-syn': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['all', 'data-only', 'disable'], 'type': 'str'},
+                'timeout-send-rst': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'traffic-shaper': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'traffic-shaper-reverse': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'url-category': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'users': {'v_range': [['6.0.0', '7.6.2']], 'type': 'raw'},
+                'utm-status': {'v_range': [['6.0.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'uuid': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'vlan-cos-fwd': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'vlan-cos-rev': {'v_range': [['6.0.0', '7.6.2']], 'type': 'int'},
+                'voip-profile': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'vpntunnel': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'webfilter-profile': {'v_range': [['6.0.0', '7.6.2']], 'type': 'str'},
+                'anti-replay': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'app-group': {'v_range': [['6.2.0', '7.6.2']], 'type': 'raw'},
+                'cifs-profile': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'dnsfilter-profile': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'emailfilter-profile': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'http-policy-redirect': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'inspection-mode': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['proxy', 'flow'], 'type': 'str'},
+                'np-acceleration': {
+                    'v_range': [['6.2.0', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'ssh-filter-profile': {'v_range': [['6.2.0', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']], 'type': 'str'},
+                'ssh-policy-redirect': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'tos': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'tos-mask': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'tos-negate': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'vlan-filter': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'waf-profile': {'v_range': [['6.2.1', '7.6.2']], 'type': 'str'},
+                'webcache': {'v_range': [['6.2.1', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'webcache-https': {
+                    'v_range': [['6.2.1', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '7.6.2']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'webproxy-forward-server': {'v_range': [['6.2.1', '7.6.2']], 'type': 'str'},
+                'webproxy-profile': {'v_range': [['6.2.1', '7.6.2']], 'type': 'str'},
                 'casi-profile': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'},
-                'fsso-groups': {'v_range': [['6.2.3', '']], 'type': 'raw'},
+                'fsso-groups': {'v_range': [['6.2.3', '7.6.2']], 'type': 'raw'},
                 'decrypted-traffic-mirror': {'v_range': [['6.4.0', '6.4.0']], 'type': 'str'},
-                'cgn-log-server-grp': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '']], 'type': 'str'},
-                'policy-offload': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                '_policy_block': {'v_range': [['7.0.3', '']], 'type': 'int'}
+                'cgn-log-server-grp': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '7.6.2']], 'type': 'str'},
+                'policy-offload': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '7.6.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                '_policy_block': {'v_range': [['7.0.3', '7.6.2']], 'type': 'int'}
             }
         }
     }
