@@ -20,13 +20,14 @@ version_added: '3.3.0'
 author:
   - Hitachi Vantara LTD (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: full
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
 options:
   storage_system_info:
     description: Information about the storage system. This field is an optional field.
@@ -37,41 +38,18 @@ options:
         description: The serial number of the storage system.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for retrieving External Volume information.
     type: dict
     required: false
     suboptions:
       external_storage_serial:
-        description: The external storage serial number.
+        description: The external storage serial number. Required for the Get all external volume for specific ldev_id task.
         type: str
         required: false
       external_ldev_id:
-        description: The external LDEV ID.
-        type: int
+        description: The external LDEV ID. Required for the Get all external volume for specific ldev_id task.
+        type: str
         required: false
 
 """
@@ -91,62 +69,91 @@ EXAMPLES = """
 RETURN = """
 ansible_facts:
   description: >
-    Dictionary containing the discovered properties of the external volumes.
+    Dictionary containing the discovered properties of the external path groups.
   returned: always
   type: list
   elements: dict
   contains:
-    ldevs:
-      description: The list of external volume IDs.
+    external_path_groups:
+      description: The list of external path groups.
       type: list
       elements: dict
       contains:
-        external_ldev_id:
-          description: External LDEV ID.
-          type: int
-          sample: 1353
-        external_lun:
-          description: External lun ID.
-          type: int
-          sample: 9
         external_path_group_id:
-          description: External path group ID.
+          description: External path group number.
           type: int
-          sample: 0
-        external_product_id:
-          description: External path group ID.
-          type: str
-          sample: "VSP Gx00"
+          sample: 1
         external_serial_number:
-          description: External serial number.
+          description: Serial number of the external storage system.
           type: str
           sample: "410109"
-        external_volume_capacity:
-          description: External volume capacity.
-          type: int
-          sample: 41943040
-        external_volume_capacity_in_mb:
-          description: External volume capacity in MB.
-          type: float
-          sample: 20480.0
-        external_volume_info:
-          description: External volume information.
+        storage_serial_number:
+          description: Serial number of the storage system.
           type: str
-          sample: "OPEN-V HITACHI 5040277D0549"
-        external_wwn:
-          description: External WWN.
-          type: str
-          sample: "50060e8012277d61"
-        ldev_ids:
-          description: External volume capacity.
+          sample: "410109"
+        external_parity_groups:
+          description: The list of external parity groups.
           type: list
-          elements: int
-          sample: [151]
-        port_id:
-          description: External WWN.
-          type: str
-          sample: "CL3-B"
-"""
+          elements: dict
+          contains:
+            cache_mode:
+              description: Cache mode.
+              type: str
+              sample: "E"
+            external_parity_group_id:
+              description: External parity group ID.
+              type: str
+              sample: "1-3"
+            external_parity_group_status:
+              description: Status of the external parity group.
+              type: str
+              sample: "NML"
+            is_data_direct_mapping:
+              description: Whether the data direct mapping attribute is enabled.
+              type: bool
+              sample: false
+            is_inflow_control_enabled:
+              description: Inflow cache control.
+              type: bool
+              sample: false
+            load_balance_mode:
+              description: The load balancing method for I/O operations for the external storage system.
+              type: str
+              sample: "N"
+            mp_blade_id:
+              description: Inflow cache control.
+              type: int
+              sample: 0
+            path_mode:
+              description: Path mode of the external storage system.
+              type: str
+              sample: "M"
+            external_luns:
+              description: List of LUNs of the external storage system.
+              type: list
+              elements: dict
+              contains:
+                external_lun:
+                  description: LUN within the ports of the external storage system.
+                  type: int
+                  sample: 2
+                external_wwn:
+                  description: WWN of the external storage system.
+                  type: str
+                  sample: "50060e8012277d71"
+                path_status:
+                  description: Status of the external path.
+                  type: str
+                  sample: "NML"
+                port_id:
+                  description: Port number.
+                  type: str
+                  sample: "CL6-B"
+                priority:
+                  description: Priority within the external path group.
+                  type: int
+                  sample: 1
+ """
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.reconciler.vsp_external_volume_reconciler import (
